@@ -14,7 +14,7 @@ use utf8;
 ## use critic (Modules::RequireExplicitPackage)
 
 package Sys::OsPackage;
-$Sys::OsPackage::VERSION = '0.1.6';
+$Sys::OsPackage::VERSION = '0.1.7';
 use Config;
 use Carp qw(carp croak confess);
 use Sys::OsRelease;
@@ -779,7 +779,7 @@ sub is_root
     my ($class_or_obj) = @_;
     my $self = class_or_obj($class_or_obj);
 
-    return ($self->sysenv("root") != 0);
+    return (defined $self->sysenv("root")) ? ($self->sysenv("root") != 0) : 0;
 }
 
 # handle various systems' packagers
@@ -912,6 +912,7 @@ sub install_module
 {
     my ($class_or_obj, $name) = @_;
     my $self = class_or_obj($class_or_obj);
+    $self->debug() and print STDERR "debug: install_module($name)\n";
 
     # check if module is installed
     if (not $self->module_installed($name)) {
@@ -1062,7 +1063,7 @@ Sys::OsPackage - install OS packages and determine if CPAN modules are packaged
 
 =head1 VERSION
 
-version 0.1.6
+version 0.1.7
 
 =head1 SYNOPSIS
 
